@@ -4,7 +4,7 @@ use 5.008009;
 use strict;
 use warnings;
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 1;
 __END__
@@ -58,6 +58,8 @@ None by default.
 	Proc::Daemon [0.18]
 	Proc::ProcessTable [0.51]
 	Term::YAP [0.03]
+	Set::Tiny [0.02]
+	Test::TempDir::Tiny [0.004]
 
 =head1 SEE ALSO
 
